package
Version:
v1.2.0
Opens a new window with list of versions in this module.
Published: Aug 25, 2026
License: AGPL-3.0, AGPL-3.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
const (
KindEmpty Kind = "empty"
KindSecret Kind = "secret"
KindSecretFile Kind = "secretfile"
KindEnv Kind = "env"
KindFile Kind = "file"
KindOther Kind = "other"
)
func (r Ref) IsEmptyFileSelection() bool
Source Files
¶
Click to show internal directories.
Click to hide internal directories.